using Nirvana.Common.ApiBase;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace YBDevice.NApi.Application.BusinessClient.AccountInfo
{
    /// <summary>
    /// 商户管理
    /// </summary>
    public interface IBusinessService
    {
        /// <summary>
        /// 获取用户资料
        /// </summary>
        /// <returns></returns>
         Task<ResultInfo> GetUserInfoAsync();
        /// <summary>
        /// 修改昵称
        /// </summary>
        /// <returns></returns>
        Task<ResultInfo> ChangeNickName(string name);
        /// <summary>
        /// 头像上传
        /// </summary>
        /// <returns></returns>
        Task<ResultInfo> UploadImgAsync(string headimg);
        /// <summary>
        /// 修改密码
        /// </summary>
        /// <returns></returns>
        Task<ResultInfo> ChangePwd(BusinessChangePwdDto businessChangePwdDto);
        /// <summary>
        /// 退出登录
        /// </summary>
        /// <param name="sessionId"></param>
        /// <returns></returns>
        Task<ResultInfo> OutLogin(string sessionId);

        Task<bool> CheckUserAsync(int userid);
    }
}
